#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_mac_access_list(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def mac_access_list_standard_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name = ET.SubElement(standard, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_seq_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id = ET.SubElement(seq, "seq-id")
        seq_id.text = kwargs.pop('seq_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        action = ET.SubElement(seq, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_source(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        source = ET.SubElement(seq, "source")
        source.text = kwargs.pop('source')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_srchost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        srchost = ET.SubElement(seq, "srchost")
        srchost.text = kwargs.pop('srchost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_src_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        src_mac_addr_mask = ET.SubElement(seq, "src-mac-addr-mask")
        src_mac_addr_mask.text = kwargs.pop('src_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        count = ET.SubElement(seq, "count")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        log = ET.SubElement(seq, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name = ET.SubElement(extended, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_seq_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id = ET.SubElement(seq, "seq-id")
        seq_id.text = kwargs.pop('seq_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        action = ET.SubElement(seq, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_source(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        source = ET.SubElement(seq, "source")
        source.text = kwargs.pop('source')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_srchost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        srchost = ET.SubElement(seq, "srchost")
        srchost.text = kwargs.pop('srchost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_src_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        src_mac_addr_mask = ET.SubElement(seq, "src-mac-addr-mask")
        src_mac_addr_mask.text = kwargs.pop('src_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dst(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dst = ET.SubElement(seq, "dst")
        dst.text = kwargs.pop('dst')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dsthost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dsthost = ET.SubElement(seq, "dsthost")
        dsthost.text = kwargs.pop('dsthost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dst_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dst_mac_addr_mask = ET.SubElement(seq, "dst-mac-addr-mask")
        dst_mac_addr_mask.text = kwargs.pop('dst_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_ethertype(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        ethertype = ET.SubElement(seq, "ethertype")
        ethertype.text = kwargs.pop('ethertype')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_vlan(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        vlan = ET.SubElement(seq, "vlan")
        vlan.text = kwargs.pop('vlan')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        count = ET.SubElement(seq, "count")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        log = ET.SubElement(seq, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        interface_type = ET.SubElement(input, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        interface_name = ET.SubElement(input, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        direction = ET.SubElement(input, "direction")
        direction.text = kwargs.pop('direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_ingress_policy_policy_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        ingress_policy = ET.SubElement(interface, "ingress-policy")
        policy_name = ET.SubElement(ingress_policy, "policy-name")
        policy_name.text = kwargs.pop('policy_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_egress_policy_policy_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        egress_policy = ET.SubElement(interface, "egress-policy")
        policy_name = ET.SubElement(egress_policy, "policy-name")
        policy_name.text = kwargs.pop('policy_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name = ET.SubElement(standard, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_seq_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id = ET.SubElement(seq, "seq-id")
        seq_id.text = kwargs.pop('seq_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        action = ET.SubElement(seq, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_source(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        source = ET.SubElement(seq, "source")
        source.text = kwargs.pop('source')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_srchost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        srchost = ET.SubElement(seq, "srchost")
        srchost.text = kwargs.pop('srchost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_src_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        src_mac_addr_mask = ET.SubElement(seq, "src-mac-addr-mask")
        src_mac_addr_mask.text = kwargs.pop('src_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        count = ET.SubElement(seq, "count")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_standard_hide_mac_acl_std_seq_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        standard = ET.SubElement(access_list, "standard")
        name_key = ET.SubElement(standard, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_std = ET.SubElement(standard, "hide-mac-acl-std")
        seq = ET.SubElement(hide_mac_acl_std, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        log = ET.SubElement(seq, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name = ET.SubElement(extended, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_seq_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id = ET.SubElement(seq, "seq-id")
        seq_id.text = kwargs.pop('seq_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        action = ET.SubElement(seq, "action")
        action.text = kwargs.pop('action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_source(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        source = ET.SubElement(seq, "source")
        source.text = kwargs.pop('source')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_srchost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        srchost = ET.SubElement(seq, "srchost")
        srchost.text = kwargs.pop('srchost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_src_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        src_mac_addr_mask = ET.SubElement(seq, "src-mac-addr-mask")
        src_mac_addr_mask.text = kwargs.pop('src_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dst(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dst = ET.SubElement(seq, "dst")
        dst.text = kwargs.pop('dst')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dsthost(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dsthost = ET.SubElement(seq, "dsthost")
        dsthost.text = kwargs.pop('dsthost')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_dst_mac_addr_mask(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        dst_mac_addr_mask = ET.SubElement(seq, "dst-mac-addr-mask")
        dst_mac_addr_mask.text = kwargs.pop('dst_mac_addr_mask')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_ethertype(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        ethertype = ET.SubElement(seq, "ethertype")
        ethertype.text = kwargs.pop('ethertype')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_vlan(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        vlan = ET.SubElement(seq, "vlan")
        vlan.text = kwargs.pop('vlan')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_count(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        count = ET.SubElement(seq, "count")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def mac_access_list_extended_hide_mac_acl_ext_seq_log(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        mac = ET.SubElement(config, "mac", xmlns="urn:brocade.com:mgmt:brocade-mac-access-list")
        access_list = ET.SubElement(mac, "access-list")
        extended = ET.SubElement(access_list, "extended")
        name_key = ET.SubElement(extended, "name")
        name_key.text = kwargs.pop('name')
        hide_mac_acl_ext = ET.SubElement(extended, "hide-mac-acl-ext")
        seq = ET.SubElement(hide_mac_acl_ext, "seq")
        seq_id_key = ET.SubElement(seq, "seq-id")
        seq_id_key.text = kwargs.pop('seq_id')
        log = ET.SubElement(seq, "log")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        interface_type = ET.SubElement(input, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        interface_name = ET.SubElement(input, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_input_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        input = ET.SubElement(get_mac_acl_for_intf, "input")
        direction = ET.SubElement(input, "direction")
        direction.text = kwargs.pop('direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_ingress_policy_policy_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        ingress_policy = ET.SubElement(interface, "ingress-policy")
        policy_name = ET.SubElement(ingress_policy, "policy-name")
        policy_name.text = kwargs.pop('policy_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_mac_acl_for_intf_output_interface_egress_policy_policy_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_mac_acl_for_intf = ET.Element("get_mac_acl_for_intf")
        config = get_mac_acl_for_intf
        output = ET.SubElement(get_mac_acl_for_intf, "output")
        interface = ET.SubElement(output, "interface")
        interface_type_key = ET.SubElement(interface, "interface-type")
        interface_type_key.text = kwargs.pop('interface_type')
        interface_name_key = ET.SubElement(interface, "interface-name")
        interface_name_key.text = kwargs.pop('interface_name')
        egress_policy = ET.SubElement(interface, "egress-policy")
        policy_name = ET.SubElement(egress_policy, "policy-name")
        policy_name.text = kwargs.pop('policy_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_clock(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def clock_sa_clock_timezone(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        clock_sa = ET.SubElement(config, "clock-sa", xmlns="urn:brocade.com:mgmt:brocade-clock")
        clock = ET.SubElement(clock_sa, "clock")
        timezone = ET.SubElement(clock, "timezone")
        timezone.text = kwargs.pop('timezone')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        input = ET.SubElement(show_clock, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        rbridge_id_out = ET.SubElement(clock_time, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_current_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        current_time = ET.SubElement(clock_time, "current-time")
        current_time.text = kwargs.pop('current_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_timezone(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        timezone = ET.SubElement(clock_time, "timezone")
        timezone.text = kwargs.pop('timezone')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def clock_sa_clock_timezone(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        clock_sa = ET.SubElement(config, "clock-sa", xmlns="urn:brocade.com:mgmt:brocade-clock")
        clock = ET.SubElement(clock_sa, "clock")
        timezone = ET.SubElement(clock, "timezone")
        timezone.text = kwargs.pop('timezone')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        input = ET.SubElement(show_clock, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        rbridge_id_out = ET.SubElement(clock_time, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_current_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        current_time = ET.SubElement(clock_time, "current-time")
        current_time.text = kwargs.pop('current_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_clock_output_clock_time_timezone(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_clock = ET.Element("show_clock")
        config = show_clock
        output = ET.SubElement(show_clock, "output")
        clock_time = ET.SubElement(output, "clock-time")
        timezone = ET.SubElement(clock_time, "timezone")
        timezone.text = kwargs.pop('timezone')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET
from pynos.versions.base.yang.brocade_rbridge import brocade_rbridge
import pynos.utilities


class Firmware(object):
    """
    System class containing all system level methods and attributes.
    """

    def __init__(self, callback):
        """System init method.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            System Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    def download(self, protocol, host, user, password,
                 file_name, rbridge='all'):
        """
        Download firmware to device
        """
        urn = "{urn:brocade.com:mgmt:brocade-firmware}"
        request_fwdl = self.get_firmware_download_request(protocol, host,
                                                          user, password,
                                                          file_name, rbridge)
        response = self._callback(request_fwdl, 'get')
        fwdl_result = None
        for item in response.findall('%scluster-output' % urn):
            fwdl_result = item.find('%sfwdl-msg' % urn).text
        if not fwdl_result:
            fwdl_result = response.find('%sfwdl-cmd-msg' % urn).text
        return fwdl_result

    def download_status(self, ip_address, session_id=None):
        urn = "{urn:brocade.com:mgmt:brocade-firmware}"
        status_request = ET.Element(
            "fwdl-status", xmlns="urn:brocade.com:mgmt:brocade-firmware")
        response = self._callback(status_request, 'get')
        fwdl_status = ''
        for item in response.findall('%sfwdl-entries' % urn):
            fwdl_status = item.find('%smessage' % urn).text
        return fwdl_status

    @staticmethod
    def get_firmware_download_request(protocol, host, user_name, password,
                                      file_name, rbridge):
        request_ver = ET.Element("firmware-download",
                                 xmlns="urn:brocade.com:mgmt:brocade-firmware")
        protocol = ET.SubElement(request_ver, protocol)
        user = ET.SubElement(protocol, "user")
        user.text = user_name
        passwords = ET.SubElement(protocol, "password")
        passwords.text = password
        host_ip = ET.SubElement(protocol, "host")
        host_ip.text = host
        directory = ET.SubElement(protocol, "directory")
        directory.text = file_name
        rbridge_id = ET.SubElement(request_ver, "rbridge-id")
        rbridge_id.text = rbridge
        ET.SubElement(request_ver, "coldboot")
        return request_ver



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class ietf_netconf_notifications(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def netconf_config_change_changed_by_server_or_user_server_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        server = ET.SubElement(server_or_user, "server")
        server = ET.SubElement(server, "server")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        username = ET.SubElement(by_user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        session_id = ET.SubElement(by_user, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        source_host = ET.SubElement(by_user, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_datastore(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        datastore = ET.SubElement(netconf_config_change, "datastore")
        datastore.text = kwargs.pop('datastore')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_edit_target(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        edit = ET.SubElement(netconf_config_change, "edit")
        target = ET.SubElement(edit, "target")
        target.text = kwargs.pop('target')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_edit_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        edit = ET.SubElement(netconf_config_change, "edit")
        operation = ET.SubElement(edit, "operation")
        operation.text = kwargs.pop('operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_server_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        server = ET.SubElement(server_or_user, "server")
        server = ET.SubElement(server, "server")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        username = ET.SubElement(by_user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        session_id = ET.SubElement(by_user, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        source_host = ET.SubElement(by_user, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_session_start, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_session_start, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_session_start, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_session_end, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_session_end, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_session_end, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_killed_by(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        killed_by = ET.SubElement(netconf_session_end, "killed-by")
        killed_by.text = kwargs.pop('killed_by')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_termination_reason(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        termination_reason = ET.SubElement(netconf_session_end, "termination-reason")
        termination_reason.text = kwargs.pop('termination_reason')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_confirmed_commit, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_confirmed_commit, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_confirmed_commit, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_confirm_event(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        confirm_event = ET.SubElement(netconf_confirmed_commit, "confirm-event")
        confirm_event.text = kwargs.pop('confirm_event')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        timeout = ET.SubElement(netconf_confirmed_commit, "timeout")
        timeout.text = kwargs.pop('timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_server_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        server = ET.SubElement(server_or_user, "server")
        server = ET.SubElement(server, "server")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        username = ET.SubElement(by_user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        session_id = ET.SubElement(by_user, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_changed_by_server_or_user_by_user_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_config_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        source_host = ET.SubElement(by_user, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_datastore(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        datastore = ET.SubElement(netconf_config_change, "datastore")
        datastore.text = kwargs.pop('datastore')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_edit_target(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        edit = ET.SubElement(netconf_config_change, "edit")
        target = ET.SubElement(edit, "target")
        target.text = kwargs.pop('target')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_config_change_edit_operation(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_config_change = ET.SubElement(config, "netconf-config-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        edit = ET.SubElement(netconf_config_change, "edit")
        operation = ET.SubElement(edit, "operation")
        operation.text = kwargs.pop('operation')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_server_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        server = ET.SubElement(server_or_user, "server")
        server = ET.SubElement(server, "server")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        username = ET.SubElement(by_user, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        session_id = ET.SubElement(by_user, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_capability_change_changed_by_server_or_user_by_user_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_capability_change = ET.SubElement(config, "netconf-capability-change", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        changed_by = ET.SubElement(netconf_capability_change, "changed-by")
        server_or_user = ET.SubElement(changed_by, "server-or-user")
        by_user = ET.SubElement(server_or_user, "by-user")
        source_host = ET.SubElement(by_user, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_session_start, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_session_start, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_start_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_start = ET.SubElement(config, "netconf-session-start", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_session_start, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_session_end, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_session_end, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_session_end, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_killed_by(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        killed_by = ET.SubElement(netconf_session_end, "killed-by")
        killed_by.text = kwargs.pop('killed_by')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_session_end_termination_reason(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_session_end = ET.SubElement(config, "netconf-session-end", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        termination_reason = ET.SubElement(netconf_session_end, "termination-reason")
        termination_reason.text = kwargs.pop('termination_reason')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        username = ET.SubElement(netconf_confirmed_commit, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        session_id = ET.SubElement(netconf_confirmed_commit, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        source_host = ET.SubElement(netconf_confirmed_commit, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_confirm_event(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        confirm_event = ET.SubElement(netconf_confirmed_commit, "confirm-event")
        confirm_event.text = kwargs.pop('confirm_event')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_confirmed_commit_timeout(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_confirmed_commit = ET.SubElement(config, "netconf-confirmed-commit", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-notifications")
        timeout = ET.SubElement(netconf_confirmed_commit, "timeout")
        timeout.text = kwargs.pop('timeout')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import xml.etree.ElementTree as ET

import pynos.utilities
from pynos.versions.base.yang.brocade_rbridge import brocade_rbridge


class Services(object):
    """
    The Services class holds all relevent methods and attributes for enabling
    and disabling NOS services, such as VRRP.

    Attributes:
        None
    """
    def __init__(self, callback):
        """
        Services object init.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            Services Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    @property
    def arp(self):
        """dict: trill link details
                """
        xmlns = 'urn:brocade.com:mgmt:brocade-arp'
        get_arp_info = ET.Element('get-arp', xmlns=xmlns)
        results = self._callback(get_arp_info, handler='get')
        result = []
        for item in results.findall('{%s}arp-entry' % xmlns):
            ip_address = item.find('{%s}ip-address' % xmlns).text
            mac_address = item.find('{%s}mac-address' % xmlns).text
            interface_type = item.find('{%s}interface-type' % xmlns).text
            interface_name = item.find('{%s}interface-name' % xmlns).text
            is_resolved = item.find('{%s}is-resolved' % xmlns).text
            age = item.find('{%s}age' % xmlns).text
            entry_type = item.find('{%s}entry-type' % xmlns).text
            item_results = {'ip-address': ip_address,
                            'mac-address': mac_address,
                            'interface-type': interface_type,
                            'interface-name': interface_name,
                            'is-resolved': is_resolved,
                            'age': age,
                            'entry-type': entry_type
                            }
            result.append(item_results)
        return result

    def vrrp(self, **kwargs):
        """Enable or Disable VRRP.

        Args:
            ip_version (str): The IP version ('4' or '6') for which VRRP should
                be enabled/disabled.  Default: `4`.
            enabled (bool): If VRRP should be enabled or disabled.  Default:
                ``True``.
            rbridge_id (str): The rbridge ID of the device on which VRRP will
                be enabled/disabled.  Default: `1`.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            None

        Examples:
            >>> import pynos.device
            >>> switches = ['10.24.39.211', '10.24.39.203']
            >>> auth = ('admin', 'password')
            >>> for switch in switches:
            ...     conn = (switch, '22')
            ...     with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...         output = dev.bgp.local_asn(rbridge_id='225')
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         enabled=False)
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         ip_version='6')
            ...         output = dev.bgp.local_asn(rbridge_id='225',
            ...         enabled=False, ip_version='6')
            ...         dev.services.vrrp() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        ip_version = kwargs.pop('ip_version', '4')
        enabled = kwargs.pop('enabled', True)
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        vrrp_args = dict(rbridge_id=rbridge_id)
        vrrp_method = 'rbridge_id_protocol_hide_vrrp_holder_vrrp'
        if ip_version == '6':
            vrrp_method = 'rbridge_id_ipv6_proto_vrrpv3_vrrp'
        vrrp = getattr(self._rbridge, vrrp_method)
        config = vrrp(**vrrp_args)
        if not enabled:
            config.find('.//*vrrp').set('operation', 'delete')
        return callback(config)

    def vrrpe(self, **kwargs):
        """Enable or Disable Vrrpe.
        Args:
            ip_version (str): The IP version ('4' or '6') for which vrrpe
                should be enabled/disabled.  Default: `4`.
            enable (bool): If vrrpe should be enabled or disabled.  Default:
                ``True``.
            get (bool): Get config instead of editing config. (True, False)
            rbridge_id (str): The rbridge ID of the device on which vrrpe will
                be enabled/disabled.  Default: `1`.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            None

        Examples:
            >>> import pynos.device
            >>> switches = ['10.24.39.211', '10.24.39.203']
            >>> auth = ('admin', 'password')
            >>> for switch in switches:
            ...     conn = (switch, '22')
            ...     with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...         dev.services.vrrpe(rbridge_id='25',enable=False)
            ...         dev.services.vrrpe(rbridge_id='25',enable=True)
            ...         dev.services.vrrpe()
            Traceback (most recent call last):
            KeyError
        """
        ip_version = kwargs.pop('ip_version', '4')
        enable = kwargs.pop('enable', True)
        get = kwargs.pop('get', False)
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        if get:
            enable = None
        vrrpe_args = dict(rbridge_id=rbridge_id)
        vrrpe_method = 'rbridge_id_protocol_hide_vrrp_holder_vrrp_extended'
        if ip_version == '6':
            vrrpe_method = 'rbridge_id_ipv6_proto_vrrpv3_vrrp_extended'
        vrrpe = getattr(self._rbridge, vrrpe_method)
        config = vrrpe(**vrrpe_args)
        if get:
            return callback(config, handler='get_config')
        if not enable:
            config.find('.//*vrrp-extended').set('operation', 'delete')
        return callback(config)



"""
Copyright 2016 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from pynos.versions.base.system import System as BaseSystem
from pynos.versions.ver_7.ver_7_1_0.yang.brocade_rbridge import brocade_rbridge
import xml.etree.ElementTree as ET
import pynos.utilities


class System(BaseSystem):
    """System class containing all system level methods and attributes.
    """

    def __init__(self, callback):
        super(System, self).__init__(callback)
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    def maintenance_mode(self, **kwargs):
        """Configures maintenance mode on the device

        Args:
            rbridge_id (str): The rbridge ID of the device on which
            Maintenance mode
                will be configured in a VCS fabric.

            get (bool): Get config instead of editing config. (True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `rbridge_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.202', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.maintenance_mode(rbridge_id='226')
            ...     output = dev.system.maintenance_mode(rbridge_id='226',
            ...     get=True)
            ...     assert output == True
            ...     output = dev.system.maintenance_mode(rbridge_id='226',
            ...     delete=True)
            ...     output = dev.system.maintenance_mode(rbridge_id='226',
            ...     get=True)
            ...     assert output == False
        """
        is_get_config = kwargs.pop('get', False)
        delete = kwargs.pop('delete', False)
        rbridge_id = kwargs.pop('rbridge_id')
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id)
        rid = getattr(self._rbridge,
                      'rbridge_id_system_mode_maintenance')
        config = rid(**rid_args)
        if is_get_config:
            maint_mode = callback(config, handler='get_config')
            mode = maint_mode.data_xml
            root = ET.fromstring(mode)
            namespace = 'urn:brocade.com:mgmt:brocade-rbridge'
            for rbridge_id_node in root.findall('{%s}rbridge-id' % namespace):
                system_mode = rbridge_id_node.find(
                    '{%s}system-mode' % namespace)
                if system_mode is not None:
                    return True
                else:
                    return False
        if delete:
            config.find('.//*maintenance').set('operation', 'delete')
        return callback(config)



"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET


class FabricService(object):
    """
    FabricService class containing all VCS Fabric methods and attributes.
    """

    def __init__(self, callback):
        """FabricService init method.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            FabricService Object

        Raises:
            None
        """
        self._callback = callback

    @property
    def trill_links(self):
        """dict: trill link details
        """
        xmlns = 'urn:brocade.com:mgmt:brocade-fabric-service'
        get_links_info = ET.Element('show-linkinfo', xmlns=xmlns)
        results = self._callback(get_links_info, handler='get')
        result = []
        for item in results.findall('{%s}show-link-info' % xmlns):
            src_rbridge_id = item.find('{%s}linkinfo-rbridgeid' % xmlns).text
            src_switch_wwn = item.find('{%s}linkinfo-wwn' % xmlns).text
            for link in item.findall('{%s}linkinfo-isl' % xmlns):
                dest_rbridge_id = link.find(
                    '{%s}linkinfo-isllink-destdomain' % xmlns).text
                src_interface = link.find(
                    '{%s}linkinfo-isllink-srcport-interface' % xmlns).text
                dest_interface = link.find(
                    '{%s}linkinfo-isllink-destport-interface' % xmlns).text
                link_cost = link.find('{%s}linkinfo-isl-linkcost' % xmlns).text
                link_cost_count = link.find(
                    '{%s}linkinfo-isllink-costcount' % xmlns).text

                item_results = {'source-rbridgeid': src_rbridge_id,
                                'source-switch-wwn': src_switch_wwn,
                                'dest-rbridgeid': dest_rbridge_id,
                                'source-interface': src_interface,
                                'dest-interface': dest_interface,
                                'link-cost': link_cost,
                                'link-costcount': link_cost_count}

                result.append(item_results)

        return result



#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_system_monitor_ext(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def show_system_monitor_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        input = ET.SubElement(show_system_monitor, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        rbridge_id_out = ET.SubElement(switch_status, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_name = ET.SubElement(switch_status, "switch-name")
        switch_name.text = kwargs.pop('switch_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_ip = ET.SubElement(switch_status, "switch-ip")
        switch_ip.text = kwargs.pop('switch_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_report_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        report_time = ET.SubElement(switch_status, "report-time")
        report_time.text = kwargs.pop('report_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_state = ET.SubElement(switch_status, "switch-state")
        switch_state.text = kwargs.pop('switch_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_state_reason(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_state_reason = ET.SubElement(switch_status, "switch-state-reason")
        switch_state_reason.text = kwargs.pop('switch_state_reason')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_component_status_component_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        component_status = ET.SubElement(switch_status, "component-status")
        component_name = ET.SubElement(component_status, "component-name")
        component_name.text = kwargs.pop('component_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_component_status_component_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        component_status = ET.SubElement(switch_status, "component-status")
        component_state = ET.SubElement(component_status, "component-state")
        component_state.text = kwargs.pop('component_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_area(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_area = ET.SubElement(port_status, "port-area")
        port_area.text = kwargs.pop('port_area')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_name = ET.SubElement(port_status, "port-name")
        port_name.text = kwargs.pop('port_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_state = ET.SubElement(port_status, "port-state")
        port_state.text = kwargs.pop('port_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        input = ET.SubElement(show_system_monitor, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        rbridge_id_out = ET.SubElement(switch_status, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_name = ET.SubElement(switch_status, "switch-name")
        switch_name.text = kwargs.pop('switch_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_ip = ET.SubElement(switch_status, "switch-ip")
        switch_ip.text = kwargs.pop('switch_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_report_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        report_time = ET.SubElement(switch_status, "report-time")
        report_time.text = kwargs.pop('report_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_state = ET.SubElement(switch_status, "switch-state")
        switch_state.text = kwargs.pop('switch_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_switch_state_reason(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        switch_state_reason = ET.SubElement(switch_status, "switch-state-reason")
        switch_state_reason.text = kwargs.pop('switch_state_reason')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_component_status_component_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        component_status = ET.SubElement(switch_status, "component-status")
        component_name = ET.SubElement(component_status, "component-name")
        component_name.text = kwargs.pop('component_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_component_status_component_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        component_status = ET.SubElement(switch_status, "component-status")
        component_state = ET.SubElement(component_status, "component-state")
        component_state.text = kwargs.pop('component_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_area(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_area = ET.SubElement(port_status, "port-area")
        port_area.text = kwargs.pop('port_area')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_name = ET.SubElement(port_status, "port-name")
        port_name.text = kwargs.pop('port_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_system_monitor_output_switch_status_port_status_port_state(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_system_monitor = ET.Element("show_system_monitor")
        config = show_system_monitor
        output = ET.SubElement(show_system_monitor, "output")
        switch_status = ET.SubElement(output, "switch-status")
        port_status = ET.SubElement(switch_status, "port-status")
        port_state = ET.SubElement(port_status, "port-state")
        port_state.text = kwargs.pop('port_state')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


class InvalidInterfaceName(Exception):
    """Exception for invalid physical interface names.
    """
    pass


class InvalidInterfaceType(Exception):
    """Exception for invalid interface types.
    """
    pass


class InvalidVlanId(Exception):
    """Exception for invalid VLAN IDs.
    """
    pass


class InvalidPortChannelName(Exception):
    """Exception for invalid port-channel interface names.
    """
    pass


class InvalidState(Exception):
    """Exception for invalid states.
    """
    pass


class InvalidAction(Exception):
    """Exception for invalid actions.
    """
    pass


class InvalidMode(Exception):
    """Exception for invalid modes.
    """
    pass


class PynosException(Exception):
    """Exception for unique PyNOS issues with no more specific exception.
    """
    pass



"""
Copyright 2015 Brocade Communications Systems, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import pynos.utilities

from pynos.versions.base.interface import Interface as InterfaceBase
from pynos.versions.ver_6.ver_6_0_1.yang.brocade_mac_address_table \
    import brocade_mac_address_table


class Interface(InterfaceBase):
    """
    The Interface class holds all the actions assocaiated with the Interfaces
    of a NOS device.
    Attributes:
        None
    """

    def __init__(self, callback):
        """
        Interface init function.
        Args:
            callback: Callback function that will be called for each action.
        Returns:
            Interface Object
        Raises:
            None
        """
        super(Interface, self).__init__(callback)
        self._mac_address_table = brocade_mac_address_table(
            callback=pynos.utilities.return_xml
        )

    def mac_move_detect_enable(self, **kwargs):
        """Enable mac move detect enable on vdx switches
        Args:
            get (bool): Get config instead of editing config. (True, False)
            delete (bool): True, delete the mac-move-detect-enable.
                           (True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.
        Returns:
            Return value of `callback`.
        Raises:
            None
        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.interface.mac_move_detect_enable()
            ...     output = dev.interface.mac_move_detect_enable(get=True)
            ...     output = dev.interface.mac_move_detect_enable(delete=True)
        """

        callback = kwargs.pop('callback', self._callback)
        mac_move = getattr(self._mac_address_table,
                           'mac_address_table_mac_move_mac_move_'
                           'detect_enable')

        config = mac_move()
        if kwargs.pop('get', False):
            output = callback(config, handler='get_config')
            item = output.data.find('.//{*}mac-move-detect-enable')
            if item is not None:
                return True
            else:
                return None
        if kwargs.pop('delete', False):
            config.find('.//*mac-move-detect-enable').set('operation',
                                                          'delete')
        return callback(config)

    def mac_move_limit(self, **kwargs):
        """Configure mac move limit on vdx switches
        Args:
            mac_move_limit: set the limit of mac move limit
            get (bool): Get config instead of editing config. (True, False)
            delete (bool): True, delete the mac move limit.(True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.
        Returns:
            Return value of `callback`.
        Raises:
            None
        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.interface.mac_move_limit()
            ...     output = dev.interface.mac_move_limit(get=True)
            ...     output = dev.interface.mac_move_limit(delete=True)
        """

        callback = kwargs.pop('callback', self._callback)
        get_config = kwargs.pop('get', False)
        delete = kwargs.pop('delete', False)
        if not get_config:
            if not delete:
                mac_move_limit = kwargs.pop('mac_move_limit')
                mac_move = getattr(self._mac_address_table,
                                   'mac_address_table_mac_move_'
                                   'mac_move_limit')
                config = mac_move(mac_move_limit=mac_move_limit)
            else:
                mac_move = getattr(self._mac_address_table,
                                   'mac_address_table_mac_move_'
                                   'mac_move_limit')
                config = mac_move(mac_move_limit='')
                config.find('.//*mac-move-limit').set('operation',
                                                      'delete')
            return callback(config)

        if get_config:
            mac_move = getattr(self._mac_address_table,
                               'mac_address_table_mac_move_mac'
                               '_move_limit')
            config = mac_move(mac_move_limit='')
            output = callback(config, handler='get_config')
            if output.data.find('.//{*}mac-move-limit') is not None:
                limit = output.data.find('.//{*}mac-move-limit').text
                if limit is not None:
                    return limit
                else:
                    return None
            else:
                limit_default = "20"
                return limit_default
